SubscriptionUsers
SubscriptionUsers
AddUser
Add a user to the subscription, the added users will be displayed in the list of users of the subscription, and these users will also have an active subscription.
Request
PUT /api/manage/v1/Subscriptions/{subscriptionId}/users/{userId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | Idenitifier of subscription |
|
| *userId | string | Idenitifier of user |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Succesfully added |
|
| 400 | The request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or user is not found |
RemoveUser
Delete a user from the subscription,
Request
DELETE /api/manage/v1/Subscriptions/{subscriptionId}/users/{userId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | Idenitifier of subscription |
|
| *userId | string | Idenitifier of user |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Succesfully deleted |
|
| 400 | The request is wrong |
|
| 402 | Subscription id outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription or user is not found |
LeaveSubscripiton
Allows user to leave subscription,.
Request
DELETE /api/manage/v1/Subscriptions/{subscriptionId}/leave
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | Idenitifier of subscription |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | Succesfully deleted |
|
| 400 | The request is wrong |
|
| 401 | User is unauthorized |
|
| 402 | Subscription id outdated |
|
| 404 | Subscription or user is not found |
GetUsers
Returns all users of subscription
Request
GET /api/manage/v1/Subscriptions/{subscriptionId}/users[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string | Idenitifier of subscription |
|
| skip | integer | 0 | How many entities skip |
| take | integer | 10 | How many entities take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
|
| 400 | The request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription is not found |
CountUsersAsync
Returns a number of users in subscription
Request
GET /api/manage/v1/Subscriptions/{subscriptionId}/UsersCount
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *subscriptionId | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Succesfully returned |
|
| 400 | The request is wrong |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permissions for the operation |
|
| 404 | Subscription is not found |
Definitions
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
SubscriptionUsersVM
| Name | Type | Notes |
|---|---|---|
| users |
|
|
| count | integer (int64) | |
| take | integer (int32) | |
| skip | integer (int32) | |
| $t | string |
SubscriptionUserVM
| Name | Type | Notes |
|---|---|---|
| userId | string | |
| groups |
|
|
| $t | string |
GroupVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string | |
| subscriptionId | string | |
| $t | string |